;***********************************************************************;
; programme pour les allumages monts sur des moteurs monocylindres ou  ;
; assimils. Le programme comporte une temporisation pour viter les    ;
; perturbations lies aux rebonds des rupteurs. Il est conu pour les   ; 
; moteurs  un allumage tous les 2 tours.                               ;
; Il comporte :                                                         ;
; 	* un test de fonctionnement par 3 clignotements rapides  la mise   ;	
;   sous tension.                                                       ;
;	* Une fonction test qui dlivre une impulsion toutes les 1,2 secon- ;
;	des.                                                                ;
;	* Une aide au rglage de l'avance initiale.                         ;
;	* 4 courbes d'avance slectionnables par Interdils                  ;
;	* Un rglage de l'avance initiale par Interdils                     ;
;***********************************************************************;

	ERRORLEVEL -302				; suppression du message bank select 
	LIST      p=16F628       	; Dfinition de processeur
	#include <p16F628.inc>      ; fichier include

	__CONFIG   _CP_OFF & _DATA_CP_OFF & _LVP_OFF & _BODEN_OFF & _MCLRE_OFF & _PWRTE_ON & _WDT_OFF & _INTRC_OSC_NOCLKOUT
		
			
;*********************************************************************
;                              ASSIGNATIONS                          *
;*********************************************************************

OPTIONVAL	EQU	H'0001'			; Valeur registre option
                                ; Rsistance pull-up ON (bit 7  0)
								; Timer0 en interne (bit5  0)
                                ; Prscaler timer  1 (dbordement toutes les 1024s) 
								
INTERMASK	EQU H'00A0'			; Masque d'interruption
								; Validation gnrale bit7 (valeur H'0080)
								; Validation interruption timer0 bit5(valeur H'0020)

;*********************************************************************
;                             DEFINE                                 *
;*********************************************************************
#DEFINE LED		PORTA,0			; Diode Led en pin 17
#DEFINE ALLUM	PORTA,1			; Sortie allumage en Pin 18
#DEFINE RUPT	PORTA,2			; Entre rupteur en Pin 1
;#DEFINE TESTLED	PORTA,3			; Led de test sur banc

#DEFINE AVANCE2	PORTB,0			; Choix avance 0 - 1 en pin 6
#DEFINE AVANCE1	PORTB,1			; Choix avance 0 - 2 en Pin 7
#DEFINE TEST	PORTB,2			; Fonction TEST en Pin 8
#DEFINE DECAL1	PORTB,3			; Decalage avance 1 en Pin 9
#DEFINE DECAL2	PORTB,4			; Decalage avance 2 en Pin 10
#DEFINE DECAL3	PORTB,5			; Decalage avance 3 en Pin 11
#DEFINE	DECAL4	PORTB,6			; Decalage avance 4 en pin 12
#DEFINE DECAL5	PORTB,7			; Decalage avance 5 en Pin 13


;*********************************************************************
;                             MACRO                                  *
;*********************************************************************


;*********************************************************************
;                   DECLARATIONS DE VARIABLES                        *
;*********************************************************************

;exemples
;---------
	CBLOCK 0x020   				; dbut de la zone variables
	w_temp : 1					; Zone de 1 byte
	status_temp : 1				; zone de 1 byte
	cmpt1 : 1					; zone de 1 byte pour boucle de comptage
	cmpt2 : 1					; zone de 1 byte pour boucle de comptage
	cmpt3 : 1					; zone de 1 byte pour boucle de comptage

	comptage : 1				; zone de 1 byte pour comptage de la dure de 2 tours moteur
	
	dure : 1					; zone de 1 byte pour mmorisation du comptage prcdent
	retard : 1					; zone de 1 byte pour valeur du retard en pas
	
	Tempo : 1					; zone de 1 byte pour temporisation
	TempoF : 1					; zone de 1 byte pour temporisation (Poids fort)

	courbe : 1					; zone de 1 byte pour choix courbe d'avance

	drapeau : 1					; zone de 1 byte pour mmoires d'tat :
								; 0 : position rupteurs
	Hall : 1 					; zone de 1 byte pour drapeau capteur Hall
								; mettre  1 dans l'initialisation pour capteur Hall


	ENDC						; Fin de la zone       

;**********************************************************************
;                      DEMARRAGE SUR RESET                            *
;**********************************************************************

	org 0x000 					; Adresse de dpart aprs reset
  	goto    init				; Adresse 0: initialiser

;**********************************************************************
;                     ROUTINE INTERRUPTION                            *
;**********************************************************************

			;sauvegarder registres	
			;---------------------
	ORG 	0x004				; adresse d'interruption
	movwf	w_temp  			; sauver registre W
	swapf	STATUS,w			; swap status avec rsultat dans w
	movwf	status_temp			; sauver status swapp

			; switch vers diffrentes interrupts
			; inverser ordre pour modifier priorits
			;----------------------------------------
inttimer	
	incfsz	comptage,f			; incrmenter comptage, saut si 0	
	goto	index016
	decf	comptage,f

index016

	bcf		INTCON,T0IF			; revalide l'interruption tmr(0)
	
			;restaurer registres
			;-------------------
restorereg
	swapf	status_temp,w		; swap ancien status, rsultat dans w
	movwf   STATUS				; restaurer status
	swapf   w_temp,f			; Inversion L et H de l'ancien W
                       			; sans modifier Z
	swapf   w_temp,w  			; Rinversion de L et H dans W
								; W restaur sans modifier status
	retfie  					; return from interrupt

;*********************************************************************
;                       INITIALISATIONS                              *
;*********************************************************************

init
	movlw 	0x07
	movwf 	CMCON 				; Comparateurs dsactivs

	clrf	PORTA				; Sorties portA  0	
	bsf		STATUS,RP0			; slectionner banque 1	
	movlw	OPTIONVAL			; charger masque
	movwf	OPTION_REG			; initialiser registre option

	clrf	EEADR				; permet de diminuer la consommation

					; Effacer RAM
					; ------------
	movlw	0x020				; initialisation pointeur
	movwf	FSR					; pointeur d'adressage indirec
init1
	clrf	INDF				; effacer ram
	incf	FSR,f				; pointer sur suivant
	btfss	FSR,6				; tester si fin zone atteinte (>=40)
	goto	init1				; non, boucler
	btfss	FSR,4				; tester si fin zone atteinte (>=50)
	goto	init1				; non, boucler


					; Positionner les ports sortie
					; ----------------------------
	bcf 	TRISA,0				; Mettre le portA,0 en sortie (pin 17)
	bcf 	TRISA,1				; Mettre le portA,1 en sortie (pin 18)
	bcf		TRISA,3				; Mettre le portA,3 en sortie (pin 3)

	bcf		STATUS,RP0			; slectionner banque 0	

 	bsf 	LED					; Sortie Led  5V (teinte)
;	bsf		TESTLED				; Sortie Led de test  5V (teinte)

	bcf		ALLUM				; Sortie allumage  0 (ferm)

					; Charger le masque d'interruption
					; --------------------------------

	movlw	INTERMASK			; masque interruption
	movwf	INTCON				; charger interrupt control

					; Positionner drapeau capteur Hall
;	bsf		Hall,0				; pour capteur Hall
	bcf		Hall,0				; pour rupteurs
					; initialiser le drapeau de position rupteur
	bcf		drapeau,0			; mettre drapeau  0 

;*********************************************************************
;                      PROGRAMME PRINCIPAL                           *
;*********************************************************************



;------------------------------------------------------------------------
; Dbut de la boucle principale
;-------------------------------
start
test_initial
	movlw	3					; charger 3 dans le registre de travail
	movwf	cmpt3				; mettre 3 dans compteur3
test1
 	bcf		LED					; alumer la Led
	call	tempo200			; Temporisation 200 milli-secondes
 	bsf		LED 				; teindre la Led
	call	tempo200			; Temporisation 200 milli-secondes
	decfsz	cmpt3,f				; dcrmenter compteur 3
	goto	test1				; si pas  0, refaire la boucle

start1
; choix du programme
;---------------------------------------------------------------
	btfss	TEST				; Teste si Interdil de Test allumage est ouvert
	goto	Testallumage		; si ferm, aller au programme de test

; Programme d'allumage
;***************************************************************************************
	btfsc	Hall,0				; test si drapeau Hall est  1
	goto	index4				; si  1, passer  la deuxime possibilit
; 1re possibilit : allumage  rupteurs
; --------------------------------------
; positionnement de la Led d'avance
;------------------------

	btfss	RUPT				; teste si rupteur ouvert
	goto	index001			; teind la Led d'avance et retour au dbut si ferm


	btfss	drapeau,0			; teste si rupteur est deja ouvert au cycle prcdent
	goto	index002			; si mmoire rupteur dj ouvert, dsactiver drapeau et sortir

; Temporisation anti-parasites de 255s (environ 10 degrs villebrequin  8000t/mn) 		
	movlw	50					; pour 50 boucles  													1s																								 
	movwf	cmpt1				; pour 50 boucles 													1s										
index003
	btfss	RUPT				; tester rupteur . sauter si ouvert									50 x 2s				
	goto 	index001			; si rupteur ferm, retour au dbut de la boucle 
								; principale									
	decfsz	cmpt1,f				; dcrmenter compteur du filtre, saut si 0							49 x 1s +1s					
	goto	index003			; si compteur non nul, boucler										49 x 2s
	nop							; attendre 1s 														1s
	nop							; attendre 1s 														1s
	nop							; attendre 1s 														1s
	nop							; attendre 1s 														1s
	nop							; attendre 1s 														1s
	goto  	index6				; passer l'autre tempo

; 2me possibilit : allumage  capteur TLE4905
; ---------------------------------------------
; positionnement de la Led d'avance
;------------------------
index4
	btfsc	RUPT				; teste si capteur activ
	goto	index001			; teind la Led d'avance et retourne au dbut si non activ

	btfss	drapeau,0			; teste si capteur est deja activ au cycle prcdent
	goto	index002			; si mmoire capteur dj activ, dsactiver drapeau et sortir

; Temporisation de 256s (uniquement pour allumages  effet Hall)						

	movlw	10					; pour 10 boucles										1s
	movwf	cmpt1				; pour 10 boucles										1s
	nop							; attendre 1s 											1s
	nop							; attendre 1s											1s
	nop							; attendre 1s											1s
	nop							; attendre 1s											1s
index5
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	nop							; attendre 1s x 10										10s
	decfsz	cmpt1,f				; dcrmenter compteur du filtre						11s							
	goto	index5				; si compteur non nul, boucler							18s
							
index6
; Remise  0 du comptage																3s
;--------------------------------------
	Movf	comptage,w			; charger comptage dans W
	movwf	dure				; sauver dans dure
	clrf	comptage			; remettre  0
;	bsf		TESTLED

; Choix de la courbe d'avance															5s
; ---------------------------
	clrf	courbe				; mettre courbe  0
	btfss	AVANCE2				; teste position du switch AVANCE2, saut si position OFF
	incf	courbe,f			; incrmenter si position ON
	btfss	AVANCE1				; teste position du switch AVANCE1, saut si position 0FF
	bsf		courbe,1			; ajouter 2 si position ON

; branchement vers la temporisation														6s
; ---------------------------------
	movf	dure,w				; charge dure dans W
	movwf	cmpt1				; stocker dans cmpt1 pour determination du retard
	movf	courbe, f			; charge courbe pour positionner STATUS
	btfsc	STATUS,Z			; si courbe non  0, passer au test suivant	
	goto 	courbeA				; aller calculer l'avance avec la courbe A

	decf	courbe, f			; soustraire 1  courbe		
	btfsc	STATUS,Z			; si courbe non  0, passer au test suivant	
	goto 	courbeB				; aller calculer l'avance avec la courbe B

	decf	courbe, f			; soustraire 1  courbe		
	btfsc	STATUS,Z			; si courbe non  0, courbe D
	goto 	courbeC				; aller calculer l'avance avec la courbe C

	goto	courbeD				; aller calculer l'avance avec la courbe D

index7
; Test surrgime 																		5s
; --------------
	movf	retard,f			; charger retard pour positionner le bit Z
	btfsc	STATUS,Z			; saut si pas  0
;	bcf		TESTLED				; allume la Led de Test en cas de surgime
;	btfsc	STATUS,Z			; saut si pas  0
	goto	start1				; retour au dbut de la boucle si surrgime (Z=0)


; Decalage avance initiale
; ------------------------
	btfss	DECAL1				; teste position du switch DECAL1, saut si position OFF
	incf	retard,f			; incrmenter si position ON
index029
	btfsc	DECAL2				; teste position du switch DECAL2, saut si position 0N
	goto	index030
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
index030
	btfsc	DECAL3				; teste position du switch DECAL3, saut si position 0N
	goto	index031
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
index031
	btfsc	DECAL4				; teste position du switch DECAL4, saut si position 0N
	goto	index032
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
index032
	btfsc	DECAL5				; teste position du switch DECAL5, saut si position 0N
	goto	index8
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON
	incf	retard,f			; incrmenter si position ON

index8
; retirer 6 fois dure pour temps de la multiplication
; ----------------------------------------------------
	decf	retard,f			; retirer 6 fois dure pour temps de la multiplication
	decf	retard,f
	decf	retard,f
	decf	retard,f
	decf	retard,f
	decf	retard,f

	decf	retard,f			; retirer 2 fois dure pour optimisation du temps
	decf	retard,f


; calcul de la temporisation (multiplication dure par retard)
; ------------------------------------------------------------
	clrf	TempoF				; effacer rsultat poids fort			1s
	clrf	Tempo				; effacer rsultat poids faible			1s
	movf	dure,w
	movwf	cmpt1				; charger dure dans cmpt1
	movf	retard,w
index90
	addwf	Tempo,f
	btfsc	STATUS,C
	incf	TempoF,f
	decfsz	cmpt1,f
	goto	index90

index024
; retrait du temps dj coul
; ----------------------------
	decf	TempoF,f			; decrmenter 256s pour tempo de confirmation d'tat
	Movlw	d'87'				; charger la valeur 5 dans W pour choix courbe d'avance
								; charger la valeur 5 dans W pour RAZ comptage
								; charger la valeur 16 dans W pour calcul valeur retard
								; charger la valeur 3 pour le test de surrgime
								; charger la valeur 12 pour le dcalage avance initiale
								; charger la valeur 4 dans W pour division par 4 de Tempo
								; charger la valeur 3 dans W test de TempoF
								; charger la valeur 3 dans W test de Tempo
								; charger la valeur 4 dans w pour retrait du temps dj coul
								; charger la valeur 6 pour init de multiplication et de dcompte
								; charger la valeur 2 pour optimisation du calcul
								; charger la valeur 24 pour retrait du temps de la multiplication
								
	subwf	Tempo,f				; retirer le temps dj coul de Tempo
	btfss	STATUS,C			; teste si carry = 0
	decf	TempoF,f			; si carry = 0, alors dcrmenter TempoF

; retirer 6 fois la valeur de dure pour temps de la multiplication
; -----------------------------------------------------------------
	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

	movf	dure,w				; charger dure dans W
	subwf	Tempo,f				; retrancher de tempo
	btfss	STATUS,C			; carry  0 si Tempo > dure, saut si pas de carry
	decf	TempoF,f			; dcrmenter Tempo F si retenue

; division par 4 de Tempo
; -----------------------
	rrf		Tempo,f	
	rrf		Tempo,f
	movlw	b'00111111'			; masque pour enlever les 2 carry
	andwf	Tempo,f

; temporisation
; -------------
; poids fort
; ----------
	movf	TempoF,f			; charger TempoF pour positionner bit Z
	btfsc	STATUS,Z			; Si Z = 1, passer au poids faible
	goto	index12
index9
	call	Tempo251			; appel tempo 251s
	decfsz	TempoF,f			; 1s
	goto	index9				; 2s

; poids faible
; ------------
index12
	movf	Tempo,f				; charger Tempo pour positionner le bit Z
	btfsc	STATUS,Z			; Si Z = 1, passer  l'allumage
	goto	index11
index10
	nop							; attendre 1s
	decfsz	Tempo,f				; dcrmenter Tempo
	goto	index10				; boucler jusqu' 0

; allumage
; --------						
index11
	bcf		ALLUM				; debut etincelle
	call	Tempo2ms
	bsf		ALLUM				; fin etincelle	

; dsactiver drapeau rupteur ouvert
; ------------------------------------
index002
	bcf		LED					; allume la Led d'avance si ouvert
	bcf		drapeau,0			; mettre drapeau  0 (rupteur ouvert)
	goto	start1

; activer drapeau rupteur ferm
;-------------------------------------
index001
	bsf		LED					; teind la Led d'avance si ferm
	bsf		drapeau,0			; mettre drapeau  1 si ferm
	goto	start1



;**************************************************************************************************	
; --------------------------------------------------------------
; Programme de test de l'allumage=

Testallumage
	bcf		LED					; allumer la Led
	bcf		ALLUM				; dbut tincelle
	call	Tempo2ms			; temporisation de 2ms
	bsf		ALLUM				; fin tincelle
	call	tempo200			; Temporisation 200 milli-secondes
	call	tempo200			; Temporisation 200 milli-secondes
	call	tempo200			; Temporisation 200 milli-secondes
	bsf		LED					; teindre la Led
	call	tempo200			; Temporisation 200 milli-secondes
	call	tempo200			; Temporisation 200 milli-secondes
	call	tempo200			; Temporisation 200 milli-secondes
	goto	start1				; retour au choix de programme

;---------------------------------------------------------------------------------------------------
;  	SOUS-ROUTINES
;---------------------------------------------------------------------------------------------------

; 1 - Tempo de 200 millisecondes (Test  la mise sous tension)
;-------------------------------------------------------------
tempo200
	clrf	cmpt2				; effacer compteur 2
boucle2
	clrf	cmpt1				; effaces compteur 1
boucle1
	decfsz	cmpt1,f				; dcrmenter compteur 1
	goto	boucle1				; si pas 0, boucler
	decfsz	cmpt2,f				; si 0, dcrmenter compteur 2
	goto	boucle2				; si pas 0, recommencer boucle 2
	return						; retour de sous-routine


; 2 - Tempo 2 millisecondes (dure de l'tincelle)
;-------------------------------------------------

Tempo2ms
	movlw	3					; pour 3 boucles - 					1s
	movwf	cmpt2				; 									1s	
	nop							;									1s
	nop							;									1s
Tempo2ms2
	movlw	d'219'				; pour 219 boucles - 1s x 3 = 		3s
	movwf	cmpt3				; pour 219 boucles - 1s x 3 = 		3s
	nop							; 1s x 3 =							1s
	nop							; 1s x 3 =							1s
Tempo2ms1
	decfsz	cmpt3,f				; 1s x 219 x 3 =					657s
	goto	Tempo2ms1			; 2s x 219 x 3 = 					1314s
								; 1s x3 = 							3s pour saut decfsz
	decfsz	cmpt2,f				; 1s x 3 = 						3s
	goto	Tempo2ms2			; 2s x 3 = 						6s
								; 									1s pour le saut decfsz
	return

; 3 - Tempo 251s
; ---------------

Tempo251					
	movlw	d'61'				; 1s
	movwf	cmpt1				; 1s
loop2
	nop							; 61s
	decfsz	cmpt1,f				; 62s
	goto	loop2				; 120s
	nop							; 1s
	nop							; 1s
	nop							; 1s
	nop							; 1s
	return						; 2s






























; Calcul de l'avance avec la courbe A			
; -----------------------------------			
courbeA			
	movlw	4	
	movwf	PCLATH	; positionne PCLATH sur le dernier quart de la mmoire
	movf	cmpt1,w	; charge dure dans W
	sublw	d'195'	; retrancher 195 pour avance minimale en dessous de 600tr/mn
	btfsc	STATUS,C	; saut si carry  0
	goto	A003	
	movlw	d'71'	; avance mini correspondant  600tr/mn
	movwf	retard	; mettre retard  la valeur d'avance mini
	goto 	index7	; retour au programme principal
A003			
	call	avanceA	; appel du calcul de valeur TempoF suivant courbe A
	movwf	retard	; stocker la valeur de retard ramene par retlw
	goto 	index7	; retour au programme principal
			
; Calcul de l'avance avec la courbe B			
; -----------------------------------			
courbeB			
	movlw	5	
	movwf	PCLATH	; positionne PCLATH sur le dernier quart de la mmoire
	movf	cmpt1,w	; charge dure dans W
	sublw	d'195'	; retrancher 195 pour avance minimale en dessous de 600tr/mn
	btfsc	STATUS,C	; saut si carry  0
	goto	B003	; carry  0 si 76 - W < 0
	movlw	d'74'	; avance mini correspondant  600tr/mn
	movwf	retard	; mettre retard  la valeur d'avance mini
	goto 	index7	; retour au programme principal
B003			
	call	avanceB	; appel du calcul de valeur TempoF suivant courbe B
	movwf	retard	; stocker la valeur de retard ramene par retlw
	goto 	index7	
			
; Calcul de l'avance avec la courbe C			
; -----------------------------------			
courbeC			
	movlw	6	
	movwf	PCLATH	; positionne PCLATH sur le troisime quart de la mmoire
	movf	cmpt1,w	; charge dure dans W
	sublw	d'195'	; retrancher 195 pour avance minimale en dessous de 600tr/mn
	btfsc	STATUS,C	; retrancher 116 pour avance minimale (2)
	goto	C003	; carry  0 si 116 - W < 0
	movlw	d'82'	; avance mini correspondant  600tr/mn
	movwf	retard	; mettre retard  la valeur d'avance mini
	goto 	index7	; retour au programme principal
C003			
	call	avanceC	; appel du calcul de valeur TempoF suivant courbe C
	movwf	retard	; stocker la valeur de retard ramene par retlw
	goto 	index7	
			
; Calcul de l'avance avec la courbe D			
; -----------------------------------			
courbeD			
	movlw	7	
	movwf	PCLATH	; positionne PCLATH sur le troisime quart de la mmoire
	movf	cmpt1,w	; charge dure dans W
	sublw	d'195'	; retrancher 195 pour avance minimale en dessous de 600tr/mn
	btfsc	STATUS,C	; retrancher 100 pour avance minimale (7)
	goto	D003	; carry  0 si 100 - W < 0
	movlw	d'75'	; avance mini correspondant  600tr/mn
	movwf	retard	; mettre retard  la valeur d'avance mini
	goto 	index7	; retour au programme principal
D003			
	call	avanceD	; appel du calcul de valeur TempoF suivant courbe A
	movwf	retard	; stocker la valeur de retard ramene par retlw
	goto 	index7	
			
;***********************************************************************************************			
;                         		        T A B L E A U X	
;***********************************************************************************************			
; 4 - Courbe d'avance A			
; ---------------------			
	org	0x400	
avanceA			
	movf	cmpt1,w	; charge dure dans W
	addwf	PCL,f	; ajouter w  PCL
			
	retlw     	d'0'	; pour dure 1 degr = 0 s
	retlw     	d'0'	; pour dure 1 degr = 1 s
	retlw     	d'0'	; pour dure 1 degr = 2 s
	retlw     	d'0'	; pour dure 1 degr = 3 s
	retlw     	d'0'	; pour dure 1 degr = 4 s
	retlw     	d'0'	; pour dure 1 degr = 5 s
	retlw     	d'0'	; pour dure 1 degr = 6 s
	retlw     	d'0'	; pour dure 1 degr = 7 s
	retlw     	d'0'	; pour dure 1 degr = 8 s
	retlw     	d'0'	; pour dure 1 degr = 9 s
	retlw     	d'36'	; pour dure 1 degr = 10 s
	retlw     	d'36'	; pour dure 1 degr = 11 s
	retlw     	d'36'	; pour dure 1 degr = 12 s
	retlw     	d'36'	; pour dure 1 degr = 13 s
	retlw     	d'36'	; pour dure 1 degr = 14 s
	retlw     	d'36'	; pour dure 1 degr = 15 s
	retlw     	d'36'	; pour dure 1 degr = 16 s
	retlw     	d'36'	; pour dure 1 degr = 17 s
	retlw     	d'36'	; pour dure 1 degr = 18 s
	retlw     	d'36'	; pour dure 1 degr = 19 s
	retlw     	d'36'	; pour dure 1 degr = 20 s
	retlw     	d'36'	; pour dure 1 degr = 21 s
	retlw     	d'36'	; pour dure 1 degr = 22 s
	retlw     	d'36'	; pour dure 1 degr = 23 s
	retlw     	d'36'	; pour dure 1 degr = 24 s
	retlw     	d'36'	; pour dure 1 degr = 25 s
	retlw     	d'36'	; pour dure 1 degr = 26 s
	retlw     	d'38'	; pour dure 1 degr = 27 s
	retlw     	d'40'	; pour dure 1 degr = 28 s
	retlw     	d'42'	; pour dure 1 degr = 29 s
	retlw     	d'44'	; pour dure 1 degr = 30 s
	retlw     	d'46'	; pour dure 1 degr = 31 s
	retlw     	d'47'	; pour dure 1 degr = 32 s
	retlw     	d'49'	; pour dure 1 degr = 33 s
	retlw     	d'51'	; pour dure 1 degr = 34 s
	retlw     	d'52'	; pour dure 1 degr = 35 s
	retlw     	d'53'	; pour dure 1 degr = 36 s
	retlw     	d'54'	; pour dure 1 degr = 37 s
	retlw     	d'56'	; pour dure 1 degr = 38 s
	retlw     	d'57'	; pour dure 1 degr = 39 s
	retlw     	d'58'	; pour dure 1 degr = 40 s
	retlw     	d'59'	; pour dure 1 degr = 41 s
	retlw     	d'60'	; pour dure 1 degr = 42 s
	retlw     	d'61'	; pour dure 1 degr = 43 s
	retlw     	d'62'	; pour dure 1 degr = 44 s
	retlw     	d'62'	; pour dure 1 degr = 45 s
	retlw     	d'63'	; pour dure 1 degr = 46 s
	retlw     	d'64'	; pour dure 1 degr = 47 s
	retlw     	d'65'	; pour dure 1 degr = 48 s
	retlw     	d'65'	; pour dure 1 degr = 49 s
	retlw     	d'66'	; pour dure 1 degr = 50 s
	retlw     	d'67'	; pour dure 1 degr = 51 s
	retlw     	d'67'	; pour dure 1 degr = 52 s
	retlw     	d'68'	; pour dure 1 degr = 53 s
	retlw     	d'69'	; pour dure 1 degr = 54 s
	retlw     	d'69'	; pour dure 1 degr = 55 s
	retlw     	d'70'	; pour dure 1 degr = 56 s
	retlw     	d'70'	; pour dure 1 degr = 57 s
	retlw     	d'71'	; pour dure 1 degr = 58 s
	retlw     	d'71'	; pour dure 1 degr = 59 s
	retlw     	d'71'	; pour dure 1 degr = 60 s
	retlw     	d'71'	; pour dure 1 degr = 61 s
	retlw     	d'71'	; pour dure 1 degr = 62 s
	retlw     	d'71'	; pour dure 1 degr = 63 s
	retlw     	d'71'	; pour dure 1 degr = 64 s
	retlw     	d'71'	; pour dure 1 degr = 65 s
	retlw     	d'71'	; pour dure 1 degr = 66 s
	retlw     	d'71'	; pour dure 1 degr = 67 s
	retlw     	d'71'	; pour dure 1 degr = 68 s
	retlw     	d'71'	; pour dure 1 degr = 69 s
	retlw     	d'71'	; pour dure 1 degr = 70 s
	retlw     	d'71'	; pour dure 1 degr = 71 s
	retlw     	d'71'	; pour dure 1 degr = 72 s
	retlw     	d'71'	; pour dure 1 degr = 73 s
	retlw     	d'71'	; pour dure 1 degr = 74 s
	retlw     	d'71'	; pour dure 1 degr = 75 s
	retlw     	d'71'	; pour dure 1 degr = 76 s
	retlw     	d'71'	; pour dure 1 degr = 77 s
	retlw     	d'71'	; pour dure 1 degr = 78 s
	retlw     	d'71'	; pour dure 1 degr = 79 s
	retlw     	d'71'	; pour dure 1 degr = 80 s
	retlw     	d'71'	; pour dure 1 degr = 81 s
	retlw     	d'71'	; pour dure 1 degr = 82 s
	retlw     	d'71'	; pour dure 1 degr = 83 s
	retlw     	d'71'	; pour dure 1 degr = 84 s
	retlw     	d'71'	; pour dure 1 degr = 85 s
	retlw     	d'71'	; pour dure 1 degr = 86 s
	retlw     	d'71'	; pour dure 1 degr = 87 s
	retlw     	d'71'	; pour dure 1 degr = 88 s
	retlw     	d'71'	; pour dure 1 degr = 89 s
	retlw     	d'71'	; pour dure 1 degr = 90 s
	retlw     	d'71'	; pour dure 1 degr = 91 s
	retlw     	d'71'	; pour dure 1 degr = 92 s
	retlw     	d'71'	; pour dure 1 degr = 93 s
	retlw     	d'71'	; pour dure 1 degr = 94 s
	retlw     	d'71'	; pour dure 1 degr = 95 s
	retlw     	d'71'	; pour dure 1 degr = 96 s
	retlw     	d'71'	; pour dure 1 degr = 97 s
	retlw     	d'71'	; pour dure 1 degr = 98 s
	retlw     	d'71'	; pour dure 1 degr = 99 s
	retlw     	d'71'	; pour dure 1 degr = 100 s
	retlw     	d'71'	; pour dure 1 degr = 101 s
	retlw     	d'71'	; pour dure 1 degr = 102 s
	retlw     	d'71'	; pour dure 1 degr = 103 s
	retlw     	d'71'	; pour dure 1 degr = 104 s
	retlw     	d'71'	; pour dure 1 degr = 105 s
	retlw     	d'71'	; pour dure 1 degr = 106 s
	retlw     	d'71'	; pour dure 1 degr = 107 s
	retlw     	d'71'	; pour dure 1 degr = 108 s
	retlw     	d'71'	; pour dure 1 degr = 109 s
	retlw     	d'71'	; pour dure 1 degr = 110 s
	retlw     	d'71'	; pour dure 1 degr = 111 s
	retlw     	d'71'	; pour dure 1 degr = 112 s
	retlw     	d'71'	; pour dure 1 degr = 113 s
	retlw     	d'71'	; pour dure 1 degr = 114 s
	retlw     	d'71'	; pour dure 1 degr = 115 s
	retlw     	d'71'	; pour dure 1 degr = 116 s
	retlw     	d'71'	; pour dure 1 degr = 117 s
	retlw     	d'71'	; pour dure 1 degr = 118 s
	retlw     	d'71'	; pour dure 1 degr = 119 s
	retlw     	d'71'	; pour dure 1 degr = 120 s
	retlw     	d'71'	; pour dure 1 degr = 121 s
	retlw     	d'71'	; pour dure 1 degr = 122 s
	retlw     	d'71'	; pour dure 1 degr = 123 s
	retlw     	d'71'	; pour dure 1 degr = 124 s
	retlw     	d'71'	; pour dure 1 degr = 125 s
	retlw     	d'71'	; pour dure 1 degr = 126 s
	retlw     	d'71'	; pour dure 1 degr = 127 s
	retlw     	d'71'	; pour dure 1 degr = 128 s
	retlw     	d'71'	; pour dure 1 degr = 129 s
	retlw     	d'71'	; pour dure 1 degr = 130 s
	retlw     	d'71'	; pour dure 1 degr = 131 s
	retlw     	d'71'	; pour dure 1 degr = 132 s
	retlw     	d'71'	; pour dure 1 degr = 133 s
	retlw     	d'71'	; pour dure 1 degr = 134 s
	retlw     	d'71'	; pour dure 1 degr = 135 s
	retlw     	d'71'	; pour dure 1 degr = 136 s
	retlw     	d'71'	; pour dure 1 degr = 137 s
	retlw     	d'71'	; pour dure 1 degr = 138 s
	retlw     	d'71'	; pour dure 1 degr = 139 s
	retlw     	d'71'	; pour dure 1 degr = 140 s
	retlw     	d'71'	; pour dure 1 degr = 141 s
	retlw     	d'71'	; pour dure 1 degr = 142 s
	retlw     	d'71'	; pour dure 1 degr = 143 s
	retlw     	d'71'	; pour dure 1 degr = 144 s
	retlw     	d'71'	; pour dure 1 degr = 145 s
	retlw     	d'71'	; pour dure 1 degr = 146 s
	retlw     	d'71'	; pour dure 1 degr = 147 s
	retlw     	d'71'	; pour dure 1 degr = 148 s
	retlw     	d'71'	; pour dure 1 degr = 149 s
	retlw     	d'71'	; pour dure 1 degr = 150 s
	retlw     	d'71'	; pour dure 1 degr = 151 s
	retlw     	d'71'	; pour dure 1 degr = 152 s
	retlw     	d'71'	; pour dure 1 degr = 153 s
	retlw     	d'71'	; pour dure 1 degr = 154 s
	retlw     	d'71'	; pour dure 1 degr = 155 s
	retlw     	d'71'	; pour dure 1 degr = 156 s
	retlw     	d'71'	; pour dure 1 degr = 157 s
	retlw     	d'71'	; pour dure 1 degr = 158 s
	retlw     	d'71'	; pour dure 1 degr = 159 s
	retlw     	d'71'	; pour dure 1 degr = 160 s
	retlw     	d'71'	; pour dure 1 degr = 161 s
	retlw     	d'71'	; pour dure 1 degr = 162 s
	retlw     	d'71'	; pour dure 1 degr = 163 s
	retlw     	d'71'	; pour dure 1 degr = 164 s
	retlw     	d'71'	; pour dure 1 degr = 165 s
	retlw     	d'71'	; pour dure 1 degr = 166 s
	retlw     	d'71'	; pour dure 1 degr = 167 s
	retlw     	d'71'	; pour dure 1 degr = 168 s
	retlw     	d'71'	; pour dure 1 degr = 169 s
	retlw     	d'71'	; pour dure 1 degr = 170 s
	retlw     	d'71'	; pour dure 1 degr = 171 s
	retlw     	d'71'	; pour dure 1 degr = 172 s
	retlw     	d'71'	; pour dure 1 degr = 173 s
	retlw     	d'71'	; pour dure 1 degr = 174 s
	retlw     	d'71'	; pour dure 1 degr = 175 s
	retlw     	d'71'	; pour dure 1 degr = 176 s
	retlw     	d'71'	; pour dure 1 degr = 177 s
	retlw     	d'71'	; pour dure 1 degr = 178 s
	retlw     	d'71'	; pour dure 1 degr = 179 s
	retlw     	d'71'	; pour dure 1 degr = 180 s
	retlw     	d'71'	; pour dure 1 degr = 181 s
	retlw     	d'71'	; pour dure 1 degr = 182 s
	retlw     	d'71'	; pour dure 1 degr = 183 s
	retlw     	d'71'	; pour dure 1 degr = 184 s
	retlw     	d'71'	; pour dure 1 degr = 185 s
	retlw     	d'71'	; pour dure 1 degr = 186 s
	retlw     	d'71'	; pour dure 1 degr = 187 s
	retlw     	d'71'	; pour dure 1 degr = 188 s
	retlw     	d'71'	; pour dure 1 degr = 189 s
	retlw     	d'71'	; pour dure 1 degr = 190 s
	retlw     	d'71'	; pour dure 1 degr = 191 s
	retlw     	d'71'	; pour dure 1 degr = 192 s
	retlw     	d'71'	; pour dure 1 degr = 193 s
	retlw     	d'71'	; pour dure 1 degr = 194 s
	retlw     	d'71'	; pour dure 1 degr = 195 s
	retlw     	d'71'	; pour dure 1 degr = 196 s
			
; 5 - Courbe d'avance B			
; ---------------------			
	org	0x500	
avanceB			
	movf	cmpt1,w	; charge dure dans W
	addwf	PCL,f	; ajouter w  PCL
			
	retlw     	d'0'	; pour dure 1 degr = 0 s
	retlw     	d'0'	; pour dure 1 degr = 1 s
	retlw     	d'0'	; pour dure 1 degr = 2 s
	retlw     	d'0'	; pour dure 1 degr = 3 s
	retlw     	d'0'	; pour dure 1 degr = 4 s
	retlw     	d'0'	; pour dure 1 degr = 5 s
	retlw     	d'0'	; pour dure 1 degr = 6 s
	retlw     	d'0'	; pour dure 1 degr = 7 s
	retlw     	d'0'	; pour dure 1 degr = 8 s
	retlw     	d'0'	; pour dure 1 degr = 9 s
	retlw     	d'37'	; pour dure 1 degr = 10 s
	retlw     	d'37'	; pour dure 1 degr = 11 s
	retlw     	d'37'	; pour dure 1 degr = 12 s
	retlw     	d'37'	; pour dure 1 degr = 13 s
	retlw     	d'37'	; pour dure 1 degr = 14 s
	retlw     	d'37'	; pour dure 1 degr = 15 s
	retlw     	d'37'	; pour dure 1 degr = 16 s
	retlw     	d'37'	; pour dure 1 degr = 17 s
	retlw     	d'37'	; pour dure 1 degr = 18 s
	retlw     	d'37'	; pour dure 1 degr = 19 s
	retlw     	d'37'	; pour dure 1 degr = 20 s
	retlw     	d'37'	; pour dure 1 degr = 21 s
	retlw     	d'37'	; pour dure 1 degr = 22 s
	retlw     	d'37'	; pour dure 1 degr = 23 s
	retlw     	d'37'	; pour dure 1 degr = 24 s
	retlw     	d'37'	; pour dure 1 degr = 25 s
	retlw     	d'37'	; pour dure 1 degr = 26 s
	retlw     	d'39'	; pour dure 1 degr = 27 s
	retlw     	d'41'	; pour dure 1 degr = 28 s
	retlw     	d'43'	; pour dure 1 degr = 29 s
	retlw     	d'44'	; pour dure 1 degr = 30 s
	retlw     	d'46'	; pour dure 1 degr = 31 s
	retlw     	d'47'	; pour dure 1 degr = 32 s
	retlw     	d'49'	; pour dure 1 degr = 33 s
	retlw     	d'50'	; pour dure 1 degr = 34 s
	retlw     	d'51'	; pour dure 1 degr = 35 s
	retlw     	d'52'	; pour dure 1 degr = 36 s
	retlw     	d'53'	; pour dure 1 degr = 37 s
	retlw     	d'54'	; pour dure 1 degr = 38 s
	retlw     	d'55'	; pour dure 1 degr = 39 s
	retlw     	d'56'	; pour dure 1 degr = 40 s
	retlw     	d'57'	; pour dure 1 degr = 41 s
	retlw     	d'58'	; pour dure 1 degr = 42 s
	retlw     	d'59'	; pour dure 1 degr = 43 s
	retlw     	d'60'	; pour dure 1 degr = 44 s
	retlw     	d'60'	; pour dure 1 degr = 45 s
	retlw     	d'61'	; pour dure 1 degr = 46 s
	retlw     	d'62'	; pour dure 1 degr = 47 s
	retlw     	d'62'	; pour dure 1 degr = 48 s
	retlw     	d'63'	; pour dure 1 degr = 49 s
	retlw     	d'64'	; pour dure 1 degr = 50 s
	retlw     	d'64'	; pour dure 1 degr = 51 s
	retlw     	d'65'	; pour dure 1 degr = 52 s
	retlw     	d'65'	; pour dure 1 degr = 53 s
	retlw     	d'66'	; pour dure 1 degr = 54 s
	retlw     	d'66'	; pour dure 1 degr = 55 s
	retlw     	d'67'	; pour dure 1 degr = 56 s
	retlw     	d'67'	; pour dure 1 degr = 57 s
	retlw     	d'68'	; pour dure 1 degr = 58 s
	retlw     	d'68'	; pour dure 1 degr = 59 s
	retlw     	d'68'	; pour dure 1 degr = 60 s
	retlw     	d'69'	; pour dure 1 degr = 61 s
	retlw     	d'69'	; pour dure 1 degr = 62 s
	retlw     	d'70'	; pour dure 1 degr = 63 s
	retlw     	d'70'	; pour dure 1 degr = 64 s
	retlw     	d'70'	; pour dure 1 degr = 65 s
	retlw     	d'71'	; pour dure 1 degr = 66 s
	retlw     	d'71'	; pour dure 1 degr = 67 s
	retlw     	d'71'	; pour dure 1 degr = 68 s
	retlw     	d'72'	; pour dure 1 degr = 69 s
	retlw     	d'72'	; pour dure 1 degr = 70 s
	retlw     	d'72'	; pour dure 1 degr = 71 s
	retlw     	d'72'	; pour dure 1 degr = 72 s
	retlw     	d'73'	; pour dure 1 degr = 73 s
	retlw     	d'73'	; pour dure 1 degr = 74 s
	retlw     	d'73'	; pour dure 1 degr = 75 s
	retlw     	d'73'	; pour dure 1 degr = 76 s
	retlw     	d'74'	; pour dure 1 degr = 77 s
	retlw     	d'74'	; pour dure 1 degr = 78 s
	retlw     	d'74'	; pour dure 1 degr = 79 s
	retlw     	d'74'	; pour dure 1 degr = 80 s
	retlw     	d'74'	; pour dure 1 degr = 81 s
	retlw     	d'74'	; pour dure 1 degr = 82 s
	retlw     	d'74'	; pour dure 1 degr = 83 s
	retlw     	d'74'	; pour dure 1 degr = 84 s
	retlw     	d'74'	; pour dure 1 degr = 85 s
	retlw     	d'74'	; pour dure 1 degr = 86 s
	retlw     	d'74'	; pour dure 1 degr = 87 s
	retlw     	d'74'	; pour dure 1 degr = 88 s
	retlw     	d'74'	; pour dure 1 degr = 89 s
	retlw     	d'74'	; pour dure 1 degr = 90 s
	retlw     	d'74'	; pour dure 1 degr = 91 s
	retlw     	d'74'	; pour dure 1 degr = 92 s
	retlw     	d'74'	; pour dure 1 degr = 93 s
	retlw     	d'74'	; pour dure 1 degr = 94 s
	retlw     	d'74'	; pour dure 1 degr = 95 s
	retlw     	d'74'	; pour dure 1 degr = 96 s
	retlw     	d'74'	; pour dure 1 degr = 97 s
	retlw     	d'74'	; pour dure 1 degr = 98 s
	retlw     	d'74'	; pour dure 1 degr = 99 s
	retlw     	d'74'	; pour dure 1 degr = 100 s
	retlw     	d'74'	; pour dure 1 degr = 101 s
	retlw     	d'74'	; pour dure 1 degr = 102 s
	retlw     	d'74'	; pour dure 1 degr = 103 s
	retlw     	d'74'	; pour dure 1 degr = 104 s
	retlw     	d'74'	; pour dure 1 degr = 105 s
	retlw     	d'74'	; pour dure 1 degr = 106 s
	retlw     	d'74'	; pour dure 1 degr = 107 s
	retlw     	d'74'	; pour dure 1 degr = 108 s
	retlw     	d'74'	; pour dure 1 degr = 109 s
	retlw     	d'74'	; pour dure 1 degr = 110 s
	retlw     	d'74'	; pour dure 1 degr = 111 s
	retlw     	d'74'	; pour dure 1 degr = 112 s
	retlw     	d'74'	; pour dure 1 degr = 113 s
	retlw     	d'74'	; pour dure 1 degr = 114 s
	retlw     	d'74'	; pour dure 1 degr = 115 s
	retlw     	d'74'	; pour dure 1 degr = 116 s
	retlw     	d'74'	; pour dure 1 degr = 117 s
	retlw     	d'74'	; pour dure 1 degr = 118 s
	retlw     	d'74'	; pour dure 1 degr = 119 s
	retlw     	d'74'	; pour dure 1 degr = 120 s
	retlw     	d'74'	; pour dure 1 degr = 121 s
	retlw     	d'74'	; pour dure 1 degr = 122 s
	retlw     	d'74'	; pour dure 1 degr = 123 s
	retlw     	d'74'	; pour dure 1 degr = 124 s
	retlw     	d'74'	; pour dure 1 degr = 125 s
	retlw     	d'74'	; pour dure 1 degr = 126 s
	retlw     	d'74'	; pour dure 1 degr = 127 s
	retlw     	d'74'	; pour dure 1 degr = 128 s
	retlw     	d'74'	; pour dure 1 degr = 129 s
	retlw     	d'74'	; pour dure 1 degr = 130 s
	retlw     	d'74'	; pour dure 1 degr = 131 s
	retlw     	d'74'	; pour dure 1 degr = 132 s
	retlw     	d'74'	; pour dure 1 degr = 133 s
	retlw     	d'74'	; pour dure 1 degr = 134 s
	retlw     	d'74'	; pour dure 1 degr = 135 s
	retlw     	d'74'	; pour dure 1 degr = 136 s
	retlw     	d'74'	; pour dure 1 degr = 137 s
	retlw     	d'74'	; pour dure 1 degr = 138 s
	retlw     	d'74'	; pour dure 1 degr = 139 s
	retlw     	d'74'	; pour dure 1 degr = 140 s
	retlw     	d'74'	; pour dure 1 degr = 141 s
	retlw     	d'74'	; pour dure 1 degr = 142 s
	retlw     	d'74'	; pour dure 1 degr = 143 s
	retlw     	d'74'	; pour dure 1 degr = 144 s
	retlw     	d'74'	; pour dure 1 degr = 145 s
	retlw     	d'74'	; pour dure 1 degr = 146 s
	retlw     	d'74'	; pour dure 1 degr = 147 s
	retlw     	d'74'	; pour dure 1 degr = 148 s
	retlw     	d'74'	; pour dure 1 degr = 149 s
	retlw     	d'74'	; pour dure 1 degr = 150 s
	retlw     	d'74'	; pour dure 1 degr = 151 s
	retlw     	d'74'	; pour dure 1 degr = 152 s
	retlw     	d'74'	; pour dure 1 degr = 153 s
	retlw     	d'74'	; pour dure 1 degr = 154 s
	retlw     	d'74'	; pour dure 1 degr = 155 s
	retlw     	d'74'	; pour dure 1 degr = 156 s
	retlw     	d'74'	; pour dure 1 degr = 157 s
	retlw     	d'74'	; pour dure 1 degr = 158 s
	retlw     	d'74'	; pour dure 1 degr = 159 s
	retlw     	d'74'	; pour dure 1 degr = 160 s
	retlw     	d'74'	; pour dure 1 degr = 161 s
	retlw     	d'74'	; pour dure 1 degr = 162 s
	retlw     	d'74'	; pour dure 1 degr = 163 s
	retlw     	d'74'	; pour dure 1 degr = 164 s
	retlw     	d'74'	; pour dure 1 degr = 165 s
	retlw     	d'74'	; pour dure 1 degr = 166 s
	retlw     	d'74'	; pour dure 1 degr = 167 s
	retlw     	d'74'	; pour dure 1 degr = 168 s
	retlw     	d'74'	; pour dure 1 degr = 169 s
	retlw     	d'74'	; pour dure 1 degr = 170 s
	retlw     	d'74'	; pour dure 1 degr = 171 s
	retlw     	d'74'	; pour dure 1 degr = 172 s
	retlw     	d'74'	; pour dure 1 degr = 173 s
	retlw     	d'74'	; pour dure 1 degr = 174 s
	retlw     	d'74'	; pour dure 1 degr = 175 s
	retlw     	d'74'	; pour dure 1 degr = 176 s
	retlw     	d'74'	; pour dure 1 degr = 177 s
	retlw     	d'74'	; pour dure 1 degr = 178 s
	retlw     	d'74'	; pour dure 1 degr = 179 s
	retlw     	d'74'	; pour dure 1 degr = 180 s
	retlw     	d'74'	; pour dure 1 degr = 181 s
	retlw     	d'74'	; pour dure 1 degr = 182 s
	retlw     	d'74'	; pour dure 1 degr = 183 s
	retlw     	d'74'	; pour dure 1 degr = 184 s
	retlw     	d'74'	; pour dure 1 degr = 185 s
	retlw     	d'74'	; pour dure 1 degr = 186 s
	retlw     	d'74'	; pour dure 1 degr = 187 s
	retlw     	d'74'	; pour dure 1 degr = 188 s
	retlw     	d'74'	; pour dure 1 degr = 189 s
	retlw     	d'74'	; pour dure 1 degr = 190 s
	retlw     	d'74'	; pour dure 1 degr = 191 s
	retlw     	d'74'	; pour dure 1 degr = 192 s
	retlw     	d'74'	; pour dure 1 degr = 193 s
	retlw     	d'74'	; pour dure 1 degr = 194 s
	retlw     	d'74'	; pour dure 1 degr = 195 s
	retlw     	d'74'	; pour dure 1 degr = 196 s
			
; 6 - Courbe d'avance C			
; ---------------------			
	org	0x600	
avanceC			
	movf	cmpt1,w	; charge dure dans W
	addwf	PCL,f	; ajouter w  PCL
			
	retlw     	d'0'	; pour dure 1 degr = 0 s
	retlw     	d'0'	; pour dure 1 degr = 1 s
	retlw     	d'0'	; pour dure 1 degr = 2 s
	retlw     	d'0'	; pour dure 1 degr = 3 s
	retlw     	d'0'	; pour dure 1 degr = 4 s
	retlw     	d'0'	; pour dure 1 degr = 5 s
	retlw     	d'0'	; pour dure 1 degr = 6 s
	retlw     	d'0'	; pour dure 1 degr = 7 s
	retlw     	d'0'	; pour dure 1 degr = 8 s
	retlw     	d'0'	; pour dure 1 degr = 9 s
	retlw     	d'38'	; pour dure 1 degr = 10 s
	retlw     	d'38'	; pour dure 1 degr = 11 s
	retlw     	d'38'	; pour dure 1 degr = 12 s
	retlw     	d'38'	; pour dure 1 degr = 13 s
	retlw     	d'38'	; pour dure 1 degr = 14 s
	retlw     	d'38'	; pour dure 1 degr = 15 s
	retlw     	d'38'	; pour dure 1 degr = 16 s
	retlw     	d'38'	; pour dure 1 degr = 17 s
	retlw     	d'38'	; pour dure 1 degr = 18 s
	retlw     	d'38'	; pour dure 1 degr = 19 s
	retlw     	d'39'	; pour dure 1 degr = 20 s
	retlw     	d'40'	; pour dure 1 degr = 21 s
	retlw     	d'41'	; pour dure 1 degr = 22 s
	retlw     	d'42'	; pour dure 1 degr = 23 s
	retlw     	d'43'	; pour dure 1 degr = 24 s
	retlw     	d'44'	; pour dure 1 degr = 25 s
	retlw     	d'45'	; pour dure 1 degr = 26 s
	retlw     	d'45'	; pour dure 1 degr = 27 s
	retlw     	d'46'	; pour dure 1 degr = 28 s
	retlw     	d'47'	; pour dure 1 degr = 29 s
	retlw     	d'47'	; pour dure 1 degr = 30 s
	retlw     	d'48'	; pour dure 1 degr = 31 s
	retlw     	d'48'	; pour dure 1 degr = 32 s
	retlw     	d'49'	; pour dure 1 degr = 33 s
	retlw     	d'49'	; pour dure 1 degr = 34 s
	retlw     	d'50'	; pour dure 1 degr = 35 s
	retlw     	d'50'	; pour dure 1 degr = 36 s
	retlw     	d'50'	; pour dure 1 degr = 37 s
	retlw     	d'51'	; pour dure 1 degr = 38 s
	retlw     	d'51'	; pour dure 1 degr = 39 s
	retlw     	d'52'	; pour dure 1 degr = 40 s
	retlw     	d'53'	; pour dure 1 degr = 41 s
	retlw     	d'54'	; pour dure 1 degr = 42 s
	retlw     	d'55'	; pour dure 1 degr = 43 s
	retlw     	d'56'	; pour dure 1 degr = 44 s
	retlw     	d'57'	; pour dure 1 degr = 45 s
	retlw     	d'58'	; pour dure 1 degr = 46 s
	retlw     	d'59'	; pour dure 1 degr = 47 s
	retlw     	d'60'	; pour dure 1 degr = 48 s
	retlw     	d'61'	; pour dure 1 degr = 49 s
	retlw     	d'61'	; pour dure 1 degr = 50 s
	retlw     	d'62'	; pour dure 1 degr = 51 s
	retlw     	d'63'	; pour dure 1 degr = 52 s
	retlw     	d'64'	; pour dure 1 degr = 53 s
	retlw     	d'64'	; pour dure 1 degr = 54 s
	retlw     	d'65'	; pour dure 1 degr = 55 s
	retlw     	d'65'	; pour dure 1 degr = 56 s
	retlw     	d'66'	; pour dure 1 degr = 57 s
	retlw     	d'67'	; pour dure 1 degr = 58 s
	retlw     	d'67'	; pour dure 1 degr = 59 s
	retlw     	d'68'	; pour dure 1 degr = 60 s
	retlw     	d'68'	; pour dure 1 degr = 61 s
	retlw     	d'69'	; pour dure 1 degr = 62 s
	retlw     	d'69'	; pour dure 1 degr = 63 s
	retlw     	d'69'	; pour dure 1 degr = 64 s
	retlw     	d'70'	; pour dure 1 degr = 65 s
	retlw     	d'70'	; pour dure 1 degr = 66 s
	retlw     	d'71'	; pour dure 1 degr = 67 s
	retlw     	d'71'	; pour dure 1 degr = 68 s
	retlw     	d'72'	; pour dure 1 degr = 69 s
	retlw     	d'72'	; pour dure 1 degr = 70 s
	retlw     	d'72'	; pour dure 1 degr = 71 s
	retlw     	d'73'	; pour dure 1 degr = 72 s
	retlw     	d'73'	; pour dure 1 degr = 73 s
	retlw     	d'73'	; pour dure 1 degr = 74 s
	retlw     	d'74'	; pour dure 1 degr = 75 s
	retlw     	d'74'	; pour dure 1 degr = 76 s
	retlw     	d'74'	; pour dure 1 degr = 77 s
	retlw     	d'75'	; pour dure 1 degr = 78 s
	retlw     	d'75'	; pour dure 1 degr = 79 s
	retlw     	d'75'	; pour dure 1 degr = 80 s
	retlw     	d'75'	; pour dure 1 degr = 81 s
	retlw     	d'76'	; pour dure 1 degr = 82 s
	retlw     	d'76'	; pour dure 1 degr = 83 s
	retlw     	d'76'	; pour dure 1 degr = 84 s
	retlw     	d'77'	; pour dure 1 degr = 85 s
	retlw     	d'77'	; pour dure 1 degr = 86 s
	retlw     	d'77'	; pour dure 1 degr = 87 s
	retlw     	d'77'	; pour dure 1 degr = 88 s
	retlw     	d'78'	; pour dure 1 degr = 89 s
	retlw     	d'78'	; pour dure 1 degr = 90 s
	retlw     	d'78'	; pour dure 1 degr = 91 s
	retlw     	d'78'	; pour dure 1 degr = 92 s
	retlw     	d'78'	; pour dure 1 degr = 93 s
	retlw     	d'79'	; pour dure 1 degr = 94 s
	retlw     	d'79'	; pour dure 1 degr = 95 s
	retlw     	d'79'	; pour dure 1 degr = 96 s
	retlw     	d'79'	; pour dure 1 degr = 97 s
	retlw     	d'79'	; pour dure 1 degr = 98 s
	retlw     	d'80'	; pour dure 1 degr = 99 s
	retlw     	d'80'	; pour dure 1 degr = 100 s
	retlw     	d'80'	; pour dure 1 degr = 101 s
	retlw     	d'80'	; pour dure 1 degr = 102 s
	retlw     	d'80'	; pour dure 1 degr = 103 s
	retlw     	d'81'	; pour dure 1 degr = 104 s
	retlw     	d'81'	; pour dure 1 degr = 105 s
	retlw     	d'81'	; pour dure 1 degr = 106 s
	retlw     	d'81'	; pour dure 1 degr = 107 s
	retlw     	d'81'	; pour dure 1 degr = 108 s
	retlw     	d'81'	; pour dure 1 degr = 109 s
	retlw     	d'81'	; pour dure 1 degr = 110 s
	retlw     	d'82'	; pour dure 1 degr = 111 s
	retlw     	d'82'	; pour dure 1 degr = 112 s
	retlw     	d'82'	; pour dure 1 degr = 113 s
	retlw     	d'82'	; pour dure 1 degr = 114 s
	retlw     	d'82'	; pour dure 1 degr = 115 s
	retlw     	d'82'	; pour dure 1 degr = 116 s
	retlw     	d'82'	; pour dure 1 degr = 117 s
	retlw     	d'82'	; pour dure 1 degr = 118 s
	retlw     	d'82'	; pour dure 1 degr = 119 s
	retlw     	d'82'	; pour dure 1 degr = 120 s
	retlw     	d'82'	; pour dure 1 degr = 121 s
	retlw     	d'82'	; pour dure 1 degr = 122 s
	retlw     	d'82'	; pour dure 1 degr = 123 s
	retlw     	d'82'	; pour dure 1 degr = 124 s
	retlw     	d'82'	; pour dure 1 degr = 125 s
	retlw     	d'82'	; pour dure 1 degr = 126 s
	retlw     	d'82'	; pour dure 1 degr = 127 s
	retlw     	d'82'	; pour dure 1 degr = 128 s
	retlw     	d'82'	; pour dure 1 degr = 129 s
	retlw     	d'82'	; pour dure 1 degr = 130 s
	retlw     	d'82'	; pour dure 1 degr = 131 s
	retlw     	d'82'	; pour dure 1 degr = 132 s
	retlw     	d'82'	; pour dure 1 degr = 133 s
	retlw     	d'82'	; pour dure 1 degr = 134 s
	retlw     	d'82'	; pour dure 1 degr = 135 s
	retlw     	d'82'	; pour dure 1 degr = 136 s
	retlw     	d'82'	; pour dure 1 degr = 137 s
	retlw     	d'82'	; pour dure 1 degr = 138 s
	retlw     	d'82'	; pour dure 1 degr = 139 s
	retlw     	d'82'	; pour dure 1 degr = 140 s
	retlw     	d'82'	; pour dure 1 degr = 141 s
	retlw     	d'82'	; pour dure 1 degr = 142 s
	retlw     	d'82'	; pour dure 1 degr = 143 s
	retlw     	d'82'	; pour dure 1 degr = 144 s
	retlw     	d'82'	; pour dure 1 degr = 145 s
	retlw     	d'82'	; pour dure 1 degr = 146 s
	retlw     	d'82'	; pour dure 1 degr = 147 s
	retlw     	d'82'	; pour dure 1 degr = 148 s
	retlw     	d'82'	; pour dure 1 degr = 149 s
	retlw     	d'82'	; pour dure 1 degr = 150 s
	retlw     	d'82'	; pour dure 1 degr = 151 s
	retlw     	d'82'	; pour dure 1 degr = 152 s
	retlw     	d'82'	; pour dure 1 degr = 153 s
	retlw     	d'82'	; pour dure 1 degr = 154 s
	retlw     	d'82'	; pour dure 1 degr = 155 s
	retlw     	d'82'	; pour dure 1 degr = 156 s
	retlw     	d'82'	; pour dure 1 degr = 157 s
	retlw     	d'82'	; pour dure 1 degr = 158 s
	retlw     	d'82'	; pour dure 1 degr = 159 s
	retlw     	d'82'	; pour dure 1 degr = 160 s
	retlw     	d'82'	; pour dure 1 degr = 161 s
	retlw     	d'82'	; pour dure 1 degr = 162 s
	retlw     	d'82'	; pour dure 1 degr = 163 s
	retlw     	d'82'	; pour dure 1 degr = 164 s
	retlw     	d'82'	; pour dure 1 degr = 165 s
	retlw     	d'82'	; pour dure 1 degr = 166 s
	retlw     	d'82'	; pour dure 1 degr = 167 s
	retlw     	d'82'	; pour dure 1 degr = 168 s
	retlw     	d'82'	; pour dure 1 degr = 169 s
	retlw     	d'82'	; pour dure 1 degr = 170 s
	retlw     	d'82'	; pour dure 1 degr = 171 s
	retlw     	d'82'	; pour dure 1 degr = 172 s
	retlw     	d'82'	; pour dure 1 degr = 173 s
	retlw     	d'82'	; pour dure 1 degr = 174 s
	retlw     	d'82'	; pour dure 1 degr = 175 s
	retlw     	d'82'	; pour dure 1 degr = 176 s
	retlw     	d'82'	; pour dure 1 degr = 177 s
	retlw     	d'82'	; pour dure 1 degr = 178 s
	retlw     	d'82'	; pour dure 1 degr = 179 s
	retlw     	d'82'	; pour dure 1 degr = 180 s
	retlw     	d'82'	; pour dure 1 degr = 181 s
	retlw     	d'82'	; pour dure 1 degr = 182 s
	retlw     	d'82'	; pour dure 1 degr = 183 s
	retlw     	d'82'	; pour dure 1 degr = 184 s
	retlw     	d'82'	; pour dure 1 degr = 185 s
	retlw     	d'82'	; pour dure 1 degr = 186 s
	retlw     	d'82'	; pour dure 1 degr = 187 s
	retlw     	d'82'	; pour dure 1 degr = 188 s
	retlw     	d'82'	; pour dure 1 degr = 189 s
	retlw     	d'82'	; pour dure 1 degr = 190 s
	retlw     	d'82'	; pour dure 1 degr = 191 s
	retlw     	d'82'	; pour dure 1 degr = 192 s
	retlw     	d'82'	; pour dure 1 degr = 193 s
	retlw     	d'82'	; pour dure 1 degr = 194 s
	retlw     	d'82'	; pour dure 1 degr = 195 s
	retlw     	d'82'	; pour dure 1 degr = 196 s
			
; 7 - Courbe d'avance D			
; ---------------------			
	org	0x700	
avanceD			
	movf	cmpt1,w	; charge dure dans W
	addwf	PCL,f	; ajouter w  PCL
			
	retlw     	d'0'	; pour dure 1 degr = 0 s
	retlw     	d'0'	; pour dure 1 degr = 1 s
	retlw     	d'0'	; pour dure 1 degr = 2 s
	retlw     	d'0'	; pour dure 1 degr = 3 s
	retlw     	d'0'	; pour dure 1 degr = 4 s
	retlw     	d'0'	; pour dure 1 degr = 5 s
	retlw     	d'0'	; pour dure 1 degr = 6 s
	retlw     	d'0'	; pour dure 1 degr = 7 s
	retlw     	d'0'	; pour dure 1 degr = 8 s
	retlw     	d'0'	; pour dure 1 degr = 9 s
	retlw     	d'31'	; pour dure 1 degr = 10 s
	retlw     	d'31'	; pour dure 1 degr = 11 s
	retlw     	d'31'	; pour dure 1 degr = 12 s
	retlw     	d'31'	; pour dure 1 degr = 13 s
	retlw     	d'31'	; pour dure 1 degr = 14 s
	retlw     	d'31'	; pour dure 1 degr = 15 s
	retlw     	d'31'	; pour dure 1 degr = 16 s
	retlw     	d'31'	; pour dure 1 degr = 17 s
	retlw     	d'31'	; pour dure 1 degr = 18 s
	retlw     	d'31'	; pour dure 1 degr = 19 s
	retlw     	d'31'	; pour dure 1 degr = 20 s
	retlw     	d'31'	; pour dure 1 degr = 21 s
	retlw     	d'31'	; pour dure 1 degr = 22 s
	retlw     	d'31'	; pour dure 1 degr = 23 s
	retlw     	d'31'	; pour dure 1 degr = 24 s
	retlw     	d'31'	; pour dure 1 degr = 25 s
	retlw     	d'31'	; pour dure 1 degr = 26 s
	retlw     	d'31'	; pour dure 1 degr = 27 s
	retlw     	d'31'	; pour dure 1 degr = 28 s
	retlw     	d'33'	; pour dure 1 degr = 29 s
	retlw     	d'35'	; pour dure 1 degr = 30 s
	retlw     	d'37'	; pour dure 1 degr = 31 s
	retlw     	d'38'	; pour dure 1 degr = 32 s
	retlw     	d'40'	; pour dure 1 degr = 33 s
	retlw     	d'42'	; pour dure 1 degr = 34 s
	retlw     	d'43'	; pour dure 1 degr = 35 s
	retlw     	d'44'	; pour dure 1 degr = 36 s
	retlw     	d'46'	; pour dure 1 degr = 37 s
	retlw     	d'47'	; pour dure 1 degr = 38 s
	retlw     	d'48'	; pour dure 1 degr = 39 s
	retlw     	d'49'	; pour dure 1 degr = 40 s
	retlw     	d'50'	; pour dure 1 degr = 41 s
	retlw     	d'51'	; pour dure 1 degr = 42 s
	retlw     	d'52'	; pour dure 1 degr = 43 s
	retlw     	d'53'	; pour dure 1 degr = 44 s
	retlw     	d'54'	; pour dure 1 degr = 45 s
	retlw     	d'55'	; pour dure 1 degr = 46 s
	retlw     	d'56'	; pour dure 1 degr = 47 s
	retlw     	d'56'	; pour dure 1 degr = 48 s
	retlw     	d'57'	; pour dure 1 degr = 49 s
	retlw     	d'58'	; pour dure 1 degr = 50 s
	retlw     	d'59'	; pour dure 1 degr = 51 s
	retlw     	d'59'	; pour dure 1 degr = 52 s
	retlw     	d'60'	; pour dure 1 degr = 53 s
	retlw     	d'60'	; pour dure 1 degr = 54 s
	retlw     	d'61'	; pour dure 1 degr = 55 s
	retlw     	d'62'	; pour dure 1 degr = 56 s
	retlw     	d'62'	; pour dure 1 degr = 57 s
	retlw     	d'63'	; pour dure 1 degr = 58 s
	retlw     	d'63'	; pour dure 1 degr = 59 s
	retlw     	d'64'	; pour dure 1 degr = 60 s
	retlw     	d'64'	; pour dure 1 degr = 61 s
	retlw     	d'64'	; pour dure 1 degr = 62 s
	retlw     	d'65'	; pour dure 1 degr = 63 s
	retlw     	d'65'	; pour dure 1 degr = 64 s
	retlw     	d'66'	; pour dure 1 degr = 65 s
	retlw     	d'66'	; pour dure 1 degr = 66 s
	retlw     	d'67'	; pour dure 1 degr = 67 s
	retlw     	d'67'	; pour dure 1 degr = 68 s
	retlw     	d'67'	; pour dure 1 degr = 69 s
	retlw     	d'68'	; pour dure 1 degr = 70 s
	retlw     	d'68'	; pour dure 1 degr = 71 s
	retlw     	d'68'	; pour dure 1 degr = 72 s
	retlw     	d'69'	; pour dure 1 degr = 73 s
	retlw     	d'69'	; pour dure 1 degr = 74 s
	retlw     	d'69'	; pour dure 1 degr = 75 s
	retlw     	d'70'	; pour dure 1 degr = 76 s
	retlw     	d'70'	; pour dure 1 degr = 77 s
	retlw     	d'70'	; pour dure 1 degr = 78 s
	retlw     	d'70'	; pour dure 1 degr = 79 s
	retlw     	d'71'	; pour dure 1 degr = 80 s
	retlw     	d'71'	; pour dure 1 degr = 81 s
	retlw     	d'71'	; pour dure 1 degr = 82 s
	retlw     	d'72'	; pour dure 1 degr = 83 s
	retlw     	d'72'	; pour dure 1 degr = 84 s
	retlw     	d'72'	; pour dure 1 degr = 85 s
	retlw     	d'72'	; pour dure 1 degr = 86 s
	retlw     	d'72'	; pour dure 1 degr = 87 s
	retlw     	d'73'	; pour dure 1 degr = 88 s
	retlw     	d'73'	; pour dure 1 degr = 89 s
	retlw     	d'73'	; pour dure 1 degr = 90 s
	retlw     	d'73'	; pour dure 1 degr = 91 s
	retlw     	d'74'	; pour dure 1 degr = 92 s
	retlw     	d'74'	; pour dure 1 degr = 93 s
	retlw     	d'74'	; pour dure 1 degr = 94 s
	retlw     	d'74'	; pour dure 1 degr = 95 s
	retlw     	d'74'	; pour dure 1 degr = 96 s
	retlw     	d'75'	; pour dure 1 degr = 97 s
	retlw     	d'75'	; pour dure 1 degr = 98 s
	retlw     	d'75'	; pour dure 1 degr = 99 s
	retlw     	d'75'	; pour dure 1 degr = 100 s
	retlw     	d'75'	; pour dure 1 degr = 101 s
	retlw     	d'75'	; pour dure 1 degr = 102 s
	retlw     	d'75'	; pour dure 1 degr = 103 s
	retlw     	d'75'	; pour dure 1 degr = 104 s
	retlw     	d'75'	; pour dure 1 degr = 105 s
	retlw     	d'75'	; pour dure 1 degr = 106 s
	retlw     	d'75'	; pour dure 1 degr = 107 s
	retlw     	d'75'	; pour dure 1 degr = 108 s
	retlw     	d'75'	; pour dure 1 degr = 109 s
	retlw     	d'75'	; pour dure 1 degr = 110 s
	retlw     	d'75'	; pour dure 1 degr = 111 s
	retlw     	d'75'	; pour dure 1 degr = 112 s
	retlw     	d'75'	; pour dure 1 degr = 113 s
	retlw     	d'75'	; pour dure 1 degr = 114 s
	retlw     	d'75'	; pour dure 1 degr = 115 s
	retlw     	d'75'	; pour dure 1 degr = 116 s
	retlw     	d'75'	; pour dure 1 degr = 117 s
	retlw     	d'75'	; pour dure 1 degr = 118 s
	retlw     	d'75'	; pour dure 1 degr = 119 s
	retlw     	d'75'	; pour dure 1 degr = 120 s
	retlw     	d'75'	; pour dure 1 degr = 121 s
	retlw     	d'75'	; pour dure 1 degr = 122 s
	retlw     	d'75'	; pour dure 1 degr = 123 s
	retlw     	d'75'	; pour dure 1 degr = 124 s
	retlw     	d'75'	; pour dure 1 degr = 125 s
	retlw     	d'75'	; pour dure 1 degr = 126 s
	retlw     	d'75'	; pour dure 1 degr = 127 s
	retlw     	d'75'	; pour dure 1 degr = 128 s
	retlw     	d'75'	; pour dure 1 degr = 129 s
	retlw     	d'75'	; pour dure 1 degr = 130 s
	retlw     	d'75'	; pour dure 1 degr = 131 s
	retlw     	d'75'	; pour dure 1 degr = 132 s
	retlw     	d'75'	; pour dure 1 degr = 133 s
	retlw     	d'75'	; pour dure 1 degr = 134 s
	retlw     	d'75'	; pour dure 1 degr = 135 s
	retlw     	d'75'	; pour dure 1 degr = 136 s
	retlw     	d'75'	; pour dure 1 degr = 137 s
	retlw     	d'75'	; pour dure 1 degr = 138 s
	retlw     	d'75'	; pour dure 1 degr = 139 s
	retlw     	d'75'	; pour dure 1 degr = 140 s
	retlw     	d'75'	; pour dure 1 degr = 141 s
	retlw     	d'75'	; pour dure 1 degr = 142 s
	retlw     	d'75'	; pour dure 1 degr = 143 s
	retlw     	d'75'	; pour dure 1 degr = 144 s
	retlw     	d'75'	; pour dure 1 degr = 145 s
	retlw     	d'75'	; pour dure 1 degr = 146 s
	retlw     	d'75'	; pour dure 1 degr = 147 s
	retlw     	d'75'	; pour dure 1 degr = 148 s
	retlw     	d'75'	; pour dure 1 degr = 149 s
	retlw     	d'75'	; pour dure 1 degr = 150 s
	retlw     	d'75'	; pour dure 1 degr = 151 s
	retlw     	d'75'	; pour dure 1 degr = 152 s
	retlw     	d'75'	; pour dure 1 degr = 153 s
	retlw     	d'75'	; pour dure 1 degr = 154 s
	retlw     	d'75'	; pour dure 1 degr = 155 s
	retlw     	d'75'	; pour dure 1 degr = 156 s
	retlw     	d'75'	; pour dure 1 degr = 157 s
	retlw     	d'75'	; pour dure 1 degr = 158 s
	retlw     	d'75'	; pour dure 1 degr = 159 s
	retlw     	d'75'	; pour dure 1 degr = 160 s
	retlw     	d'75'	; pour dure 1 degr = 161 s
	retlw     	d'75'	; pour dure 1 degr = 162 s
	retlw     	d'75'	; pour dure 1 degr = 163 s
	retlw     	d'75'	; pour dure 1 degr = 164 s
	retlw     	d'75'	; pour dure 1 degr = 165 s
	retlw     	d'75'	; pour dure 1 degr = 166 s
	retlw     	d'75'	; pour dure 1 degr = 167 s
	retlw     	d'75'	; pour dure 1 degr = 168 s
	retlw     	d'75'	; pour dure 1 degr = 169 s
	retlw     	d'75'	; pour dure 1 degr = 170 s
	retlw     	d'75'	; pour dure 1 degr = 171 s
	retlw     	d'75'	; pour dure 1 degr = 172 s
	retlw     	d'75'	; pour dure 1 degr = 173 s
	retlw     	d'75'	; pour dure 1 degr = 174 s
	retlw     	d'75'	; pour dure 1 degr = 175 s
	retlw     	d'75'	; pour dure 1 degr = 176 s
	retlw     	d'75'	; pour dure 1 degr = 177 s
	retlw     	d'75'	; pour dure 1 degr = 178 s
	retlw     	d'75'	; pour dure 1 degr = 179 s
	retlw     	d'75'	; pour dure 1 degr = 180 s
	retlw     	d'75'	; pour dure 1 degr = 181 s
	retlw     	d'75'	; pour dure 1 degr = 182 s
	retlw     	d'75'	; pour dure 1 degr = 183 s
	retlw     	d'75'	; pour dure 1 degr = 184 s
	retlw     	d'75'	; pour dure 1 degr = 185 s
	retlw     	d'75'	; pour dure 1 degr = 186 s
	retlw     	d'75'	; pour dure 1 degr = 187 s
	retlw     	d'75'	; pour dure 1 degr = 188 s
	retlw     	d'75'	; pour dure 1 degr = 189 s
	retlw     	d'75'	; pour dure 1 degr = 190 s
	retlw     	d'75'	; pour dure 1 degr = 191 s
	retlw     	d'75'	; pour dure 1 degr = 192 s
	retlw     	d'75'	; pour dure 1 degr = 193 s
	retlw     	d'75'	; pour dure 1 degr = 194 s
	retlw     	d'75'	; pour dure 1 degr = 195 s
	retlw     	d'75'	; pour dure 1 degr = 196 s
			
;*******************************************************			
	END 		; directive fin de programme
;*******************************************************			
			
